@@ -7,9 +7,17 @@
 #include <Python.h>
 #include <stdio.h>
 #include <stdlib.h>
+#if defined (__APPLE__) || defined(__FreeBSD__) || \
+    defined(__OpenBSD__) || defined(__NetBSD__)
+#include <stdlib.h>
+#else
 #include <malloc.h>
+#endif
 #include <string.h>
 #include <inttypes.h>
+#ifndef linux
+typedef unsigned long ulong;
+#endif
 #include <sys/types.h>
 #include <lzma.h>
 
@@ -43,7 +51,7 @@
 
 #define INITCHECK if (!self->is_initialised) {	PyErr_Format(PyExc_RuntimeError, "%s object not initialised!", self->ob_type->tp_name);	return NULL; }
 
-PyObject *libLZMAError;
+extern PyObject *libLZMAError;
 
 bool CatchlibLZMAError(lzma_ret lzuerror, lzma_stream *lzus);
 
