@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 import sys, md5, random
-import liblzma
+import lzma
 import unittest
 from binascii import unhexlify
 from cStringIO import StringIO
@@ -53,22 +53,22 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_compression_eopm(self):
         # test compression with end of payload marker
-        compressed = liblzma.compress(self.plain, eopm=True)
+        compressed = lzma.compress(self.plain, eopm=True)
         self.assertEqual(compressed, self.plain_with_eopm)
 
     def test_compression_noeopm(self):
         # test compression without end of payload marker
-        compressed = liblzma.compress(self.plain, eopm=False)
+        compressed = lzma.compress(self.plain, eopm=False)
         self.assertEqual(compressed, self.plain_without_eopm)
 
     def test_decompression_eopm(self):
         # test decompression with end of payload marker
-        decompressed = liblzma.decompress(self.plain_with_eopm)
+        decompressed = lzma.decompress(self.plain_with_eopm)
         self.assertEqual(decompressed, self.plain)
         
     def test_decompression_noeopm(self):
         # test decompression without end of payload marker
-        decompressed = liblzma.decompress(self.plain_without_eopm)
+        decompressed = lzma.decompress(self.plain_without_eopm)
         self.assertEqual(decompressed, self.plain)
 
     def test_compression_decompression_eopm(self, dictionary_size=1<<23):
@@ -76,7 +76,7 @@ class TestlibLZMA(unittest.TestCase):
         for i in xrange(18):
             size = 1 << i
             original = generate_random(size)
-            result = liblzma.decompress(liblzma.compress(original, eopm=True, dictionary_size=dictionary_size))
+            result = lzma.decompress(lzma.compress(original, eopm=True, dictionary_size=dictionary_size))
             self.assertEqual(len(result), size)
             self.assertEqual(md5.new(original).hexdigest(), md5.new(result).hexdigest())
 
@@ -85,7 +85,7 @@ class TestlibLZMA(unittest.TestCase):
         for i in xrange(18):
             size = 1 << i
             original = generate_random(size)
-            result = liblzma.decompress(liblzma.compress(original, eopm=False, dictionary_size=dictionary_size))
+            result = lzma.decompress(lzma.compress(original, eopm=False, dictionary_size=dictionary_size))
             self.assertEqual(len(result), size)
             self.assertEqual(md5.new(original).hexdigest(), md5.new(result).hexdigest())
 
@@ -97,14 +97,14 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_decompression_stream(self):
         # test decompression object in one steps
-        decompress = liblzma.LZMADecompressor()
+        decompress = lzma.LZMADecompressor()
         data = decompress.decompress(self.plain_without_eopm)
         data += decompress.flush()
         self.assertEqual(data, self.plain)
     
     def test_decompression_stream_two(self):
         # test decompression in two steps
-        decompress = liblzma.LZMADecompressor()
+        decompress = lzma.LZMADecompressor()
         data = decompress.decompress(self.plain_without_eopm[:10])
         data += decompress.decompress(self.plain_without_eopm[10:])
         data += decompress.flush()
@@ -112,7 +112,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_decompression_stream_props(self):
         # test decompression with properties in separate step
-        decompress = liblzma.LZMADecompressor()
+        decompress = lzma.LZMADecompressor()
         data = decompress.decompress(self.plain_without_eopm[:5])
         data += decompress.decompress(self.plain_without_eopm[5:])
         data += decompress.flush()
@@ -120,7 +120,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_decompression_stream_reset(self):
         # test reset
-        decompress = liblzma.LZMADecompressor()
+        decompress = lzma.LZMADecompressor()
         data = decompress.decompress(self.plain_without_eopm[:10])
         decompress.reset()
         data = decompress.decompress(self.plain_without_eopm[:15])
@@ -130,7 +130,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_decompression_streaming_eopm(self):
         # test decompressing with one byte at a time...
-        decompress = liblzma.LZMADecompressor()
+        decompress = lzma.LZMADecompressor()
         infile = StringIO(self.plain_with_eopm)
         outfile = StringIO()
         while 1:
@@ -142,7 +142,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_decompression_streaming_noeopm(self):
         # test decompressing with one byte at a time...
-        decompress = liblzma.LZMADecompressor()
+        decompress = lzma.LZMADecompressor()
         infile = StringIO(self.plain_without_eopm)
         outfile = StringIO()
         while 1:
@@ -154,14 +154,14 @@ class TestlibLZMA(unittest.TestCase):
     
     def test_compression_stream(self):
         # test compression object in one steps
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         data = compress.compress(self.plain)
         data += compress.flush()
         self.assertEqual(data, self.plain_with_eopm)
     
     def test_compression_stream_two(self):
         # test compression in two steps
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         data = compress.compress(self.plain[:10])
         data += compress.compress(self.plain[10:])
         data += compress.flush()
@@ -169,7 +169,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_compression_stream_props(self):
         # test compression with properties in separate step
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         data = compress.compress(self.plain[:5])
         data += compress.compress(self.plain[5:])
         data += compress.flush()
@@ -177,7 +177,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_compression_stream_reset(self):
         # test reset
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         data = compress.compress(self.plain[:10])
         compress.reset()
         data = compress.compress(self.plain[:15])
@@ -187,7 +187,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_compression_streaming_noeopm(self):
         # test compressing with one byte at a time...
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         infile = StringIO(self.plain)
         outfile = StringIO()
         while 1:
@@ -199,13 +199,13 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_compress_large_string(self):
         # decompress large block of repeating data, string version
-        compressed = liblzma.compress(self.data_large)
-        self.failUnless(self.data_large == liblzma.decompress(compressed))
+        compressed = lzma.compress(self.data_large)
+        self.failUnless(self.data_large == lzma.decompress(compressed))
 
     def test_decompress_large_stream(self):
         # decompress large block of repeating data, stream version
-        decompress = liblzma.LZMADecompressor()
-        infile = StringIO(liblzma.compress(self.data_large))
+        decompress = lzma.LZMADecompressor()
+        infile = StringIO(lzma.compress(self.data_large))
         outfile = StringIO()
         while 1:
             tmp = infile.read(1)
@@ -216,8 +216,8 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_decompress_large_stream_bigchunks(self):
         # decompress large block of repeating data, stream version with big chunks
-        decompress = liblzma.LZMADecompressor()
-        infile = StringIO(liblzma.compress(self.data_large))
+        decompress = lzma.LZMADecompressor()
+        infile = StringIO(lzma.compress(self.data_large))
         outfile = StringIO()
         while 1:
             tmp = infile.read(1024)
@@ -228,7 +228,7 @@ class TestlibLZMA(unittest.TestCase):
 
     def test_compress_large_stream(self):
         # compress large block of repeating data, stream version
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         infile = StringIO(self.data_large)
         outfile = StringIO()
         while 1:
@@ -236,11 +236,11 @@ class TestlibLZMA(unittest.TestCase):
             if not tmp: break
             outfile.write(compress.compress(tmp))
         outfile.write(compress.flush())
-        self.failUnless(liblzma.compress(self.data_large, eopm=True) == outfile.getvalue())
+        self.failUnless(lzma.compress(self.data_large, eopm=True) == outfile.getvalue())
 
     def test_compress_large_stream_bigchunks(self):
         # compress large block of repeating data, stream version with big chunks
-        compress = liblzma.LZMACompressor()
+        compress = lzma.LZMACompressor()
         infile = StringIO(self.data_large)
         outfile = StringIO()
         while 1:
@@ -248,11 +248,11 @@ class TestlibLZMA(unittest.TestCase):
             if not tmp: break
             outfile.write(compress.compress(tmp))
         outfile.write(compress.flush())
-        self.failUnless(liblzma.compress(self.data_large, eopm=True) == outfile.getvalue())
+        self.failUnless(lzma.compress(self.data_large, eopm=True) == outfile.getvalue())
 
     def test_decompress_new_format(self):
         infile = open('tests/data/teststring-newformat.lzma')
-        outstring = liblzma.decompress(infile.read())
+        outstring = lzma.decompress(infile.read())
         infile.close()
         self.assertEqual(self.plain, outstring)
 
@@ -260,84 +260,84 @@ class TestlibLZMAOptions(unittest.TestCase):
     def setUp(self):
         self.data = "kosogklem"*(1<<10)
     def test_preset_levels(self):
-        for lvl in xrange(liblzma.options.level[0], liblzma.options.level[1]+1):
-            result = liblzma.compress(self.data, level=lvl)
-            self.assertEqual(self.data, liblzma.decompress(result))
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, level=liblzma.options.level[1]+1)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, level=liblzma.options.level[0]-1)
+        for lvl in xrange(lzma.options.level[0], lzma.options.level[1]+1):
+            result = lzma.compress(self.data, level=lvl)
+            self.assertEqual(self.data, lzma.decompress(result))
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, level=lzma.options.level[1]+1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, level=lzma.options.level[0]-1)
 
     def test_dictionary_size(self):
-        dict = liblzma.options.dictionary_size[0]
-        while dict <= 1<<26: # liblzma.options.dictionary_size[1]: Since using very large dictionaries requires
+        dict = lzma.options.dictionary_size[0]
+        while dict <= 1<<26: # lzma.options.dictionary_size[1]: Since using very large dictionaries requires
                              # very large amount of memory, let's not go beyond 64mb for testing..
-            result = liblzma.compress(self.data, dictionary_size=dict)
-            self.assertEqual(self.data, liblzma.decompress(result))
+            result = lzma.compress(self.data, dictionary_size=dict)
+            self.assertEqual(self.data, lzma.decompress(result))
             dict = dict * 2
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, dictionary_size=liblzma.options.dictionary_size[1]+1)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, dictionary_size=liblzma.options.dictionary_size[0]-1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, dictionary_size=lzma.options.dictionary_size[1]+1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, dictionary_size=lzma.options.dictionary_size[0]-1)
 
     def test_fast_bytes(self):
-        for fb in xrange(liblzma.options.fast_bytes[0], liblzma.options.fast_bytes[1]+1):
-            result = liblzma.compress(self.data, fast_bytes=fb)
-            self.assertEqual(self.data, liblzma.decompress(result))
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, fast_bytes=liblzma.options.fast_bytes[1]+1)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, fast_bytes=liblzma.options.fast_bytes[0]-1)
+        for fb in xrange(lzma.options.fast_bytes[0], lzma.options.fast_bytes[1]+1):
+            result = lzma.compress(self.data, fast_bytes=fb)
+            self.assertEqual(self.data, lzma.decompress(result))
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, fast_bytes=lzma.options.fast_bytes[1]+1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, fast_bytes=lzma.options.fast_bytes[0]-1)
 
     def test_literal_context_bits(self):
-        for lcb in xrange(liblzma.options.literal_context_bits[0], liblzma.options.literal_context_bits[1]+1):
-            result = liblzma.compress(self.data, literal_context_bits=lcb)
-            self.assertEqual(self.data, liblzma.decompress(result))
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, literal_context_bits=liblzma.options.literal_context_bits[0]-1)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, literal_context_bits=liblzma.options.literal_context_bits[1]+1)
+        for lcb in xrange(lzma.options.literal_context_bits[0], lzma.options.literal_context_bits[1]+1):
+            result = lzma.compress(self.data, literal_context_bits=lcb)
+            self.assertEqual(self.data, lzma.decompress(result))
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, literal_context_bits=lzma.options.literal_context_bits[0]-1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, literal_context_bits=lzma.options.literal_context_bits[1]+1)
 
     def test_literal_pos_bits(self):
-        for lpb in xrange(liblzma.options.literal_pos_bits[0], liblzma.options.literal_pos_bits[1]+1):
-            result = liblzma.compress(self.data, literal_pos_bits=lpb)
-            self.assertEqual(self.data, liblzma.decompress(result))
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, literal_pos_bits=liblzma.options.literal_pos_bits[0]-1)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, literal_pos_bits=liblzma.options.literal_pos_bits[1]+1)
+        for lpb in xrange(lzma.options.literal_pos_bits[0], lzma.options.literal_pos_bits[1]+1):
+            result = lzma.compress(self.data, literal_pos_bits=lpb)
+            self.assertEqual(self.data, lzma.decompress(result))
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, literal_pos_bits=lzma.options.literal_pos_bits[0]-1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, literal_pos_bits=lzma.options.literal_pos_bits[1]+1)
 
     def test_pos_bits(self):
-        for pb in xrange(liblzma.options.pos_bits[0], liblzma.options.pos_bits[1]+1):
-            result = liblzma.compress(self.data, pos_bits=pb)
-            self.assertEqual(self.data, liblzma.decompress(result))
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, pos_bits=liblzma.options.literal_pos_bits[0]-1)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, pos_bits=liblzma.options.literal_pos_bits[1]+1)
+        for pb in xrange(lzma.options.pos_bits[0], lzma.options.pos_bits[1]+1):
+            result = lzma.compress(self.data, pos_bits=pb)
+            self.assertEqual(self.data, lzma.decompress(result))
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, pos_bits=lzma.options.literal_pos_bits[0]-1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, pos_bits=lzma.options.literal_pos_bits[1]+1)
 
     def test_mode(self):
-        for md in liblzma.options.mode:
-            result = liblzma.decompress(liblzma.compress(self.data, mode=md))
+        for md in lzma.options.mode:
+            result = lzma.decompress(lzma.compress(self.data, mode=md))
             self.assertEqual(self.data, result)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, mode='foo')
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, mode='foo')
 
     def test_matchfinder(self):
-        for mf in liblzma.options.match_finder:
-            result = liblzma.decompress(liblzma.compress(self.data, match_finder=mf))
+        for mf in lzma.options.match_finder:
+            result = lzma.decompress(lzma.compress(self.data, match_finder=mf))
             self.assertEqual(self.data, result)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, match_finder='1234')
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, match_finder='1234')
 
     def test_matchfinder_cycles(self):
-        for mfc in xrange(liblzma.options.match_finder_cycles, 20):
-            result = liblzma.decompress(liblzma.compress(self.data, match_finder_cycles=mfc))
+        for mfc in xrange(lzma.options.match_finder_cycles, 20):
+            result = lzma.decompress(lzma.compress(self.data, match_finder_cycles=mfc))
             self.assertEqual(self.data, result)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, match_finder_cycles=-1)
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, match_finder_cycles=-1)
 
     def test_format(self):
-        for format in liblzma.options.format:
-            result = liblzma.decompress(liblzma.compress(self.data, format=format))
+        for format in lzma.options.format:
+            result = lzma.decompress(lzma.compress(self.data, format=format))
             self.assertEqual(self.data, result)
-        self.failUnlessRaises(ValueError, liblzma.compress, self.data, format='foo')
+        self.failUnlessRaises(ValueError, lzma.compress, self.data, format='foo')
         
 class ChecksumTestCase(unittest.TestCase):
     # checksum test cases
     def test_crc32start(self):
-        self.assertEqual(liblzma.crc32(""), liblzma.crc32("", 0))
-        self.assert_(liblzma.crc32("abc", 0xffffffff))
+        self.assertEqual(lzma.crc32(""), lzma.crc32("", 0))
+        self.assert_(lzma.crc32("abc", 0xffffffff))
 
     def test_crc32empty(self):
-        self.assertEqual(liblzma.crc32("", 0), 0)
-        self.assertEqual(liblzma.crc32("", 1), 1)
-        self.assertEqual(liblzma.crc32("", 432), 432)
+        self.assertEqual(lzma.crc32("", 0), 0)
+        self.assertEqual(lzma.crc32("", 1), 1)
+        self.assertEqual(lzma.crc32("", 432), 432)
 
     def assertEqual32(self, seen, expected):
         # 32-bit values masked -- checksums on 32- vs 64- bit machines
@@ -345,29 +345,29 @@ class ChecksumTestCase(unittest.TestCase):
         self.assertEqual(seen & 0x0FFFFFFFFL, expected & 0x0FFFFFFFFL)
 
     def test_penguins32(self):
-        self.assertEqual32(liblzma.crc32("penguin", 0), 0x0e5c1a120L)
-        self.assertEqual32(liblzma.crc32("penguin", 1), 0x43b6aa94)
+        self.assertEqual32(lzma.crc32("penguin", 0), 0x0e5c1a120L)
+        self.assertEqual32(lzma.crc32("penguin", 1), 0x43b6aa94)
 
-        self.assertEqual(liblzma.crc32("penguin"), liblzma.crc32("penguin", 0))
+        self.assertEqual(lzma.crc32("penguin"), lzma.crc32("penguin", 0))
 
     # These crc64 tests needs to be reviewed..
     def test_crc64start(self):
-        self.assertEqual(liblzma.crc64(""), liblzma.crc64("", 0))
-        self.assert_(liblzma.crc64("abc", 0xffffffff))
+        self.assertEqual(lzma.crc64(""), lzma.crc64("", 0))
+        self.assert_(lzma.crc64("abc", 0xffffffff))
 
     def test_crc64empty(self):
-        self.assertEqual(liblzma.crc64("", 0), 0)
-        self.assertEqual(liblzma.crc64("", 1), 1)
-        self.assertEqual(liblzma.crc64("", 432), 432)
+        self.assertEqual(lzma.crc64("", 0), 0)
+        self.assertEqual(lzma.crc64("", 1), 1)
+        self.assertEqual(lzma.crc64("", 432), 432)
 
     def assertEqual64(self, seen, expected):
         self.assertEqual(seen & 0xFFFFFFFFFFFFFFFFL, expected & 0xFFFFFFFFFFFFFFFFL)
 
     def test_penguins64(self):
-        self.assertEqual64(liblzma.crc64("penguin", 0), 0x9285a18e774b3258)
-        self.assertEqual64(liblzma.crc64("penguin", 1), 0xb06aacd743b256b4L)
+        self.assertEqual64(lzma.crc64("penguin", 0), 0x9285a18e774b3258)
+        self.assertEqual64(lzma.crc64("penguin", 1), 0xb06aacd743b256b4L)
 
-        self.assertEqual(liblzma.crc64("penguin"), liblzma.crc64("penguin", 0))
+        self.assertEqual(lzma.crc64("penguin"), lzma.crc64("penguin", 0))
 
 def test_main():
     from test import test_support
